"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const leveldown_easier_1 = require("../leveldown-easier");
function suite({ test, factory, open_opts, trigger_put, trigger_del, }) {
    const testCommon = require('abstract-leveldown/test/common')({
        test,
        factory,
        snapshots: false,
        createIfMissing: false,
        errorIfExists: false,
    });
    require('abstract-leveldown/test/open-test').args(test, testCommon);
    require('abstract-leveldown/test/open-test').open(test, testCommon);
    require('abstract-leveldown/test/del-test').all(test, testCommon);
    require('abstract-leveldown/test/get-test').all(test, testCommon);
    require('abstract-leveldown/test/put-test').all(test, testCommon);
    require('abstract-leveldown/test/batch-test').all(test, testCommon);
    require('abstract-leveldown/test/chained-batch-test').all(test, testCommon);
    require('abstract-leveldown/test/put-get-del-test').all(test, testCommon);
    require('abstract-leveldown/test/iterator-test').all(test, testCommon);
    require('abstract-leveldown/test/iterator-range-test').all(test, testCommon);
    test('post', (t) => __awaiter(this, void 0, void 0, function* () {
        const db = new leveldown_easier_1.LevelDOWNEasier(factory());
        yield db.open(open_opts);
        const k1 = yield db.post('a');
        const v1 = yield db.get(k1);
        t.equal(String(v1), 'a');
        const k2 = yield db.post('b');
        const v2 = yield db.get(k2);
        t.equal(String(v2), 'b');
        t.notEqual(k1, k2);
        t.end();
    }));
    test('changes', (t) => __awaiter(this, void 0, void 0, function* () {
        const db = new leveldown_easier_1.LevelDOWNEasier(factory());
        if (db.changes === undefined) {
            t.comment('skipped database does not support changes');
            t.end();
        }
        yield db.open(open_opts);
        const changes = db.changes();
        const test_case = {
            key: 'a',
            value: 'b',
        };
        if (trigger_put !== undefined) {
            const put_change = new Promise((resolve, reject) => changes.onPut((key, value) => {
                resolve({ key, value });
            }));
            trigger_put(test_case);
            t.deepEqual(yield put_change, test_case);
        }
        else {
            t.comment('skipped trigger_put was not defined');
        }
        if (trigger_del !== undefined) {
            const del_change = new Promise((resolve, reject) => changes.onDel((key) => {
                resolve(key);
            }));
            trigger_del(test_case.key);
            t.equal(yield del_change, test_case.key);
        }
        else {
            t.comment('skipped trigger_del was not defined');
        }
        // TODO: batch
        t.end();
    }));
}
exports.default = suite;
//# sourceMappingURL=index.js.map